## Introduction

This document describes the assurance case for the software.

<!-- verocase element C1 -->
<!-- DO NOT EDIT text from here until "end verocase" -->
<a id="claim-c1"></a>
### Claim C1: The software is acceptably safe

Referenced by: **[Package C1](#package-c1)**

Supported by: **[Strategy AR1](#strategy-ar1)**, [Assumption A1](#assumption-a1), [Context X1](#context-x1)
<!-- end verocase -->

<!-- verocase ltac/markdown C1 -->
- [Claim C1: The software is acceptably safe](#claim-c1)
  - [Strategy AR1: Argue safety by hazard category](#strategy-ar1)
    - [Claim C2: All hazards have been identified](#claim-c2)
      - [Evidence E1: Hazard analysis](#evidence-e1) ([hara.pdf](hara.pdf))
    - [Claim C3: All hazards have been mitigated](#claim-c3)
  - [Assumption A1: Threat model is current](#assumption-a1)
  - [Context X1: Scope is release v1.0](#context-x1) ([release-notes.md](release-notes.md))
<!-- end verocase -->
